==> huaweicloudsdkvpcep-3.0.69-py2.py3-none-any.whl: huaweicloudsdkvpcep/v1/model/update_endpoint_routetable_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateEndpointRoutetableRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'routetables': 'list[str]'
    }

    attribute_map = {
        'routetables': 'routetables'
    }

    def __init__(self, routetables=None):
        """UpdateEndpointRoutetableRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._routetables = None
        self.discriminator = None

        self.routetables = routetables

    @property
    def routetables(self):
        """Gets the routetables of this UpdateEndpointRoutetableRequestBody.

        路由表ID列表。

        :return: The routetables of this UpdateEndpointRoutetableRequestBody.
        :rtype: list[str]
        """
        return self._routetables

    @routetables.setter
    def routetables(self, routetables):
        """Sets the routetables of this UpdateEndpointRoutetableRequestBody.

        路由表ID列表。

        :param routetables: The routetables of this UpdateEndpointRoutetableRequestBody.
        :type: list[str]
        """
        self._routetables = routetables

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEndpointRoutetableRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpcep-3.0.92-py2.py3-none-any.whl: huaweicloudsdkvpcep/v1/model/update_endpoint_routetable_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateEndpointRoutetableRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'routetables': 'list[str]'
    }

    attribute_map = {
        'routetables': 'routetables'
    }

    def __init__(self, routetables=None):
        """UpdateEndpointRoutetableRequestBody

        The model defined in huaweicloud sdk

        :param routetables: 路由表ID列表。
        :type routetables: list[str]
        """
        
        

        self._routetables = None
        self.discriminator = None

        self.routetables = routetables

    @property
    def routetables(self):
        """Gets the routetables of this UpdateEndpointRoutetableRequestBody.

        路由表ID列表。

        :return: The routetables of this UpdateEndpointRoutetableRequestBody.
        :rtype: list[str]
        """
        return self._routetables

    @routetables.setter
    def routetables(self, routetables):
        """Sets the routetables of this UpdateEndpointRoutetableRequestBody.

        路由表ID列表。

        :param routetables: The routetables of this UpdateEndpointRoutetableRequestBody.
        :type routetables: list[str]
        """
        self._routetables = routetables

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEndpointRoutetableRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
